@@ -56,7 +56,10 @@ class urls :
         return f'{self.base_userbroker_url}/user/warning/v2/query/tickers'
 
     def login(self):
-        return f'{self.base_user_url}/passport/login/account'
+        return f'{self.base_user_url}/passport/login/v3/account'
+
+    def get_mfa(self, account, account_type, device_id, code_type, region_code):
+        return f'{self.base_user_url}/passport/verificationCode/sendCode?account={account}&accountType={account_type}&deviceId={device_id}&codeType={code_type}&regionCode={region_code}'
 
     def logout(self):
         return f'{self.base_userbroker_url}/passport/login/logout'
